@@ -155,7 +155,7 @@ int vtkMPEG2WriterInternal::RemoveImage(const char* fname)
     {
     return 0;
     }
-  this->ImagesMap.erase(it, it);
+  this->ImagesMap.erase(it);
   return 0;
 }
 //---------------------------------------------------------------------------
@@ -163,7 +163,7 @@ int vtkMPEG2WriterInternal::RemoveImage(const char* fname)
 
 //---------------------------------------------------------------------------
 vtkStandardNewMacro(vtkMPEG2Writer);
-vtkCxxRevisionMacro(vtkMPEG2Writer, "$Revision: 1.3 $");
+vtkCxxRevisionMacro(vtkMPEG2Writer, "$Revision: 1.3.4.1 $");
 
 //---------------------------------------------------------------------------
 vtkMPEG2Writer::vtkMPEG2Writer()
